@@ -161,41 +161,6 @@ def __get_mol_cost(
     results['desirability'] = 1 - base**(1/exponent)
     return results
 
-def is_inside_box(mol:Chem.rdchem.Mol, boxcenter:List[float], boxsize:List[float], conf_id:int = 0):
-    """Chek of the conformation of the molecule is inside the box.
-
-    Parameters
-    ----------
-    mol : Chem.rdchem.Mol
-        The molecule with conformations
-    boxcenter : List[float]
-        Center of the box (x,y,z,z)
-    boxsize : List[float]
-        Size of the box (x,y,z,z)
-    conf_id : int, optional
-        The index of the conformation to analyze, by default 0
-
-    Returns
-    -------
-    bool
-        True if the molecule is inside the box, False if not.
-    """
-
-    # Get the coordinates of the conformer
-    xyz = mol.GetConformers()[conf_id].GetPositions()
-    # I have to check if they are in the same units
-    borders = np.array(
-        [
-            # (x_min, y_min, z_min),
-            np.array(boxcenter) - np.array(boxsize),
-            # (x_max, y_max, z_max),
-            np.array(boxcenter) + np.array(boxsize),
-        ]
-    ) 
-    print(xyz)
-    print(borders)
-    return ((xyz>=borders[0]) & (xyz<=borders[1])).all()
-
 def __vinadock(
     Individual:utils.Individual,
     wd:str = '.vina_jobs',
@@ -209,7 +174,6 @@ def __vinadock(
     num_modes:int = 1,
     constraint:bool = False,
     constraint_type:str = 'score_only', # score_only, local_only
-    constraint_check_inside_box:bool = False,
     constraint_ref:Chem.rdchem.Mol = None,
     constraint_receptor_pdb_path:str = None,
     constraint_num_conf:int = 100,
@@ -250,8 +214,6 @@ def __vinadock(
         (vina will perform local optimization and score the resulted pose)
         or score_only (in this case the provided pose by the internal conformer
         generator will only be scored), by default 'score_only'
-    constraint_check_inside_box : bool, optional
-        If the coordinates of the constraint conformation are outside the box; use always local_only, by default False
     constraint_ref : Chem.rdchem.Mol, optional
         The part of the molecule that we would like to constraint, by default None
     constraint_receptor_pdb_path : str, optional
@@ -273,6 +235,11 @@ def __vinadock(
         Inappropriate constraint_type. must be local_only or score_only. Only will be checked if constraint is set to True.
     """
 
+    constraint_type = constraint_type.lower()
+
+    # Creating the error directory if needed
+    if not os.path.isdir('.error'):
+        os.makedirs('.error')
     # Creating the working directory if needed
     if not os.path.exists(wd):
         os.makedirs(wd)
@@ -331,15 +298,8 @@ def __vinadock(
                 cmd_vina_str_tmp = cmd_vina_str[:]
                 cmd_vina_str_tmp += f" --ligand {os.path.join(wd, f'{Individual.idx}_conf_{conf.GetId()}.pdbqt')}"
                 
-                # Check if the molecule is outside the box
-                if constraint_check_inside_box:
-                    check = not is_inside_box(Chem.AddHs(temp_mol, addCoords=True),boxcenter, boxsize)
-                else:
-                    check = False
-                
-                if constraint_type == 'local_only' or check:
+                if constraint_type == 'local_only':
                     cmd_vina_str_tmp += f" --out {os.path.join(wd, f'{Individual.idx}_conf_{conf.GetId()}_out.pdbqt')}"
-
                 try:
                     cmd_vina_result = utils.run(cmd_vina_str_tmp)
                 except Exception as e:
@@ -358,8 +318,8 @@ def __vinadock(
                         'boxcenter': boxcenter,
                         'boxsize': boxsize,
                     }
-                    utils.compressed_pickle(f'{Individual.idx}_conf_{conf.GetId()}_error', error)
-                    warnings.warn(f"\nVina failed! Check: idx_{Individual.idx}_conf_{conf.GetId()}_error.pbz2 file.\n")
+                    utils.compressed_pickle(f'.error/idx_{Individual.idx}_conf_{conf.GetId()}_error', error)
+                    warnings.warn(f"\nVina failed! Check: idx_{Individual.idx}_conf_{conf.GetId()}_error.pbz2 file in error.\n")
                     vina_score_pdbqt = (np.inf, preparator.write_pdbqt_string())
                     return vina_score_pdbqt
 
@@ -405,8 +365,8 @@ def __vinadock(
                 'boxcenter': boxcenter,
                 'boxsize': boxsize,
             }
-            utils.compressed_pickle(f'{Individual.idx}_error', error)
-            warnings.warn(f"\nVina failed! Check: {Individual.idx}_error.pbz2 file.\n")
+            utils.compressed_pickle(f'.error/{Individual.idx}_error', error)
+            warnings.warn(f"\nVina failed! Check: {Individual.idx}_error.pbz2 file in error.\n")
 
             vina_score_pdbqt = (np.inf, 'VinaFailed')
             return vina_score_pdbqt
@@ -429,7 +389,6 @@ def Cost(
     num_modes:int = 1,
     constraint:bool = False,
     constraint_type:str = 'score_only', # score_only, local_only
-    constraint_check_inside_box:bool = False,
     constraint_ref:Chem.rdchem.Mol = None,
     constraint_receptor_pdb_path:str = None,
     constraint_num_conf:int = 100,
@@ -477,8 +436,6 @@ def Cost(
         Could be local_only (vina will perform local optimization and score the resulted pose)
         or score_only (in this case the provided pose by the internal conformer generator will only be scored),
         by default 'score_only'
-    constraint_check_inside_box : bool, optional
-        If the coordinates of the constraint conformation are outside the box us always local_only, by default False
     constraint_ref : Chem.rdchem.Mol, optional
         The part of the molecule that we would like to constraint, by default None
     constraint_receptor_pdb_path : str, optional
@@ -576,7 +533,6 @@ def Cost(
         num_modes = num_modes,
         constraint = constraint,
         constraint_type = constraint_type,
-        constraint_check_inside_box = constraint_check_inside_box,
         constraint_ref = constraint_ref,
         constraint_receptor_pdb_path = constraint_receptor_pdb_path,
         constraint_num_conf = constraint_num_conf,
@@ -618,7 +574,6 @@ def CostOnlyVina(
     num_modes:int = 1,
     constraint:bool = False,
     constraint_type:str = 'score_only', # score_only, local_only
-    constraint_check_inside_box:bool = False,
     constraint_ref:Chem.rdchem.Mol = None,
     constraint_receptor_pdb_path:str = None,
     constraint_num_conf:int = 100,
@@ -658,8 +613,6 @@ def CostOnlyVina(
         Could be local_only (vina will perform local optimization and score the resulted pose)
         or score_only (in this case the provided pose by the internal conformer generator will only be scored),
         by default 'score_only'
-    constraint_check_inside_box : bool, optional
-        If the coordinates of the constraint conformation are outside the box us always local_only, by default False
     constraint_ref : Chem.rdchem.Mol, optional
         The part of the molecule that we would like to constraint, by default None
     constraint_receptor_pdb_path : str, optional
@@ -719,7 +672,6 @@ def CostOnlyVina(
         num_modes = num_modes,
         constraint = constraint,
         constraint_type = constraint_type,
-        constraint_check_inside_box = constraint_check_inside_box,
         constraint_ref = constraint_ref,
         constraint_receptor_pdb_path = constraint_receptor_pdb_path,
         constraint_num_conf = constraint_num_conf,
@@ -742,7 +694,6 @@ def CostMultiReceptors(
     num_modes:int = 1,
     constraint:bool = False,
     constraint_type:str = 'score_only', # score_only, local_only
-    constraint_check_inside_box:bool = False,
     constraint_ref:Chem.rdchem.Mol = None,
     constraint_receptor_pdb_path:List[str] = None,
     constraint_num_conf:int = 100,
@@ -798,8 +749,6 @@ def CostMultiReceptors(
         Could be local_only (vina will perform local optimization and score the resulted pose) or
         score_only (in this case the provided pose by the internal conformer generator will only be scored),
         by default 'score_only'
-    constraint_check_inside_box : bool, optional
-        If the coordinates of the constraint conformation are outside the box us always local_only, by default False
     constraint_ref : Chem.rdchem.Mol, optional
         The part of the molecule that we would like to constraint, by default None
     constraint_receptor_pdb_path : list[str], optional
@@ -923,7 +872,6 @@ def CostMultiReceptors(
                 num_modes = num_modes,
                 constraint = constraint,
                 constraint_type = constraint_type,
-                constraint_check_inside_box = constraint_check_inside_box,
                 constraint_ref = constraint_ref,
                 constraint_receptor_pdb_path = constraint_receptor_pdb_path[i],
                 constraint_num_conf = constraint_num_conf,
@@ -1001,7 +949,6 @@ def CostMultiReceptorsOnlyVina(
     num_modes:int = 1,
     constraint:bool = False,
     constraint_type:str = 'score_only', # score_only, local_only
-    constraint_check_inside_box:bool = False,
     constraint_ref:Chem.rdchem.Mol = None,
     constraint_receptor_pdb_path:List[str] = None,
     constraint_num_conf:int = 100,
@@ -1054,8 +1001,6 @@ def CostMultiReceptorsOnlyVina(
         Could be local_only (vina will perform local optimization and score the resulted pose)
         or score_only (in this case the provided pose by the internal conformer generator will only be scored),
         by default 'score_only'
-    constraint_check_inside_box : bool, optional
-        If the coordinates of the constraint conformation are outside the box us always local_only, by default False
     constraint_ref : Chem.rdchem.Mol, optional
         The part of the molecule that we would like to constraint, by default None
     constraint_receptor_pdb_path : list[str], optional
@@ -1165,7 +1110,6 @@ def CostMultiReceptorsOnlyVina(
                 num_modes = num_modes,
                 constraint = constraint,
                 constraint_type = constraint_type,
-                constraint_check_inside_box = constraint_check_inside_box,
                 constraint_ref = constraint_ref,
                 constraint_receptor_pdb_path = constraint_receptor_pdb_path[i],
                 constraint_num_conf = constraint_num_conf,
