@@ -30,15 +30,10 @@ def home(dataDir=None):
     try:
         if sys._MEIPASS:
             homeDir = sys._MEIPASS
-    except Exception:
+    except AttributeError:
         pass
 
     if dataDir:
         return os.path.join(homeDir, "data", dataDir)
     else:
-        return homeDir
-
-if __name__ == "__main__":
-
-    h = home(dataDir='data')
-    print(h)
+        return homeDir
\ No newline at end of file
