@@ -7,9 +7,9 @@ from crem.crem import mutate_mol, grow_mol
 
 from moldrug import __version__
 from copy import deepcopy
-from inspect import getfullargspec
+from inspect import signature
 import multiprocessing as mp
-import tempfile, subprocess, random, time, datetime, shutil, tqdm, bz2, pickle, _pickle as cPickle, numpy as np, pandas as pd
+import tempfile, subprocess, random, time, datetime, shutil, os, tqdm, bz2, pickle, _pickle as cPickle, numpy as np, pandas as pd
 from warnings import warn
 from typing import List, Dict, Iterable, Union
 from scipy.special import softmax
@@ -826,6 +826,35 @@ def make_sdf(individuals:List[Individual], sdf_name = 'out'):
                     print(f"{individual} does not have a valid pdbqt: {individual.pdbqt}.")
         print(f"File {sdf_name}.sdf was createad!")
 
+def __make_kwargs_copy__(costfunc, costfunc_kwargs,):
+    """Make a copy of the self.costfunc_kwargs.
+    It creates a temporal directory.
+
+    Returns
+    -------
+    dict
+        A copy of self.costfunc_kwargs with wd changed if needed
+    """
+    kwargs_copy = costfunc_kwargs.copy()
+    costfunc_jobs_tmp_dir = tempfile.TemporaryDirectory(prefix='.costfunc_MolDrug_', dir='.')
+    if 'wd' in signature(costfunc).parameters:
+        kwargs_copy['wd'] = costfunc_jobs_tmp_dir.name
+    return kwargs_copy, costfunc_jobs_tmp_dir
+
+def __tar_errors__(error_path:str = '.error'):
+    """Clena of errors the working directory
+
+    Parameters
+    ----------
+    error_path : str
+        Where the error are storged.
+    """
+    if os.path.isdir(error_path):
+        if os.listdir(error_path):
+            shutil.make_archive('error', 'gztar', error_path)
+        shutil.rmtree(error_path)
+
+
 class Local:
     """For local search
     """
@@ -917,10 +946,7 @@ class Local:
         # Creating the arguments
         args_list = []
         # Make a copy of the self.costfunc_kwargs
-        kwargs_copy = self.costfunc_kwargs.copy()
-        if 'wd' in getfullargspec(self.costfunc).args:
-            costfunc_jobs = tempfile.TemporaryDirectory(prefix='costfunc')
-            kwargs_copy['wd'] = costfunc_jobs.name
+        kwargs_copy, costfunc_jobs_tmp_dir = __make_kwargs_copy__(self.costfunc, self.costfunc_kwargs)
 
         for individual in self.pop:
             args_list.append((individual, kwargs_copy))
@@ -930,7 +956,10 @@ class Local:
         self.pop = [individual for individual in tqdm.tqdm(pool.imap(self.__costfunc__, args_list), total=len(args_list))]
         pool.close()
 
-        if 'wd' in getfullargspec(self.costfunc).args: shutil.rmtree(costfunc_jobs.name)
+        # Clean directory
+        costfunc_jobs_tmp_dir.cleanup()
+        # Tar errors
+        __tar_errors__('error')
 
         # Printing how long was the simulation
         print(f"Finished at {datetime.datetime.now().strftime('%c')}.\n")
@@ -997,7 +1026,6 @@ def roulette_wheel_selection(p:List[float]):
     ind = np.argwhere(r <= c)
     return ind[0][0]
 
-
 def to_dataframe(individuals:List[Individual]):
     """Create a DataFrame from individuals.
 
@@ -1030,7 +1058,7 @@ class GA:
         Parameters
         ----------
         seed_mol : Union[Chem.rdchem.Mol, Iterable[Chem.rdchem.Mol]]
-            The seed molecule submited to genetic algorithm optimazation on the chemical space. Could be only one RDKit
+            The seed molecule submitted to genetic algorithm optimization on the chemical space. Could be only one RDKit
             molecule or more than one specified in an Iterable object.
         costfunc : object
             The cost function to work with (any from :mod:`moldrug.fitness` or a valid user defined).
@@ -1055,7 +1083,7 @@ class GA:
         deffnm : str, optional
             Default name for all generated files, by default 'ga'
         AddHs : bool, optional
-           If True the explicit hyrgones will be added, by default False
+           If True the explicit hydrogens will be added, by default False
         Raises
         ------
         TypeError
@@ -1063,7 +1091,7 @@ class GA:
         ValueError
             In case of incorrect definition of mutate_crem_kwargs. It must be None or a dict instance.
         """
-        self.__moldrug_version = __version__
+        self.__moldrug_version__ = __version__
         if mutate_crem_kwargs is None:
             mutate_crem_kwargs = dict()
         elif not isinstance(mutate_crem_kwargs, dict):
@@ -1124,7 +1152,7 @@ class GA:
         self.pop = []
 
     def __call__(self, njobs:int = 1):
-        """Call deffinition
+        """Call definition
 
         Parameters
         ----------
@@ -1141,10 +1169,10 @@ class GA:
         self.NumCalls += 1
 
         # Check version of MolDrug
-        if self.__moldrug_version != __version__:
-            warn.warning(f"{self.__class__.__name__} was initilized with moldrug-{self.__moldrug_version} but was called with moldrug-{__version__}")
+        if self.__moldrug_version__ != __version__:
+            warn.warning(f"{self.__class__.__name__} was initialized with moldrug-{self.__moldrug_version__} but was called with moldrug-{__version__}")
 
-        # Here we will update if needed some parameters for the crem operations that could change between differents calls.
+        # Here we will update if needed some parameters for the crem operations that could change between different calls.
         # We need to return the molecule, so we override the possible user definition respect to this keyword
         self.mutate_crem_kwargs['return_mol'] = True
 
@@ -1152,7 +1180,7 @@ class GA:
         # In case that the populating exist there is not need to initialize.
         if len(self.pop) == 0:
             GenInitStructs = []
-            # in case that the input has the posize memebrsther is not need to genereate new structures
+            # in case that the input has the popsize memebers there is not need to generate new structures
             if len(self._seed_mol) <= self.popsize:
                 for mol in self._seed_mol:
                     tmp_GenInitStructs = list(
@@ -1179,13 +1207,13 @@ class GA:
                     # Everything is ok!
                     pass
 
-            # Adding the inputs to the intial population
+            # Adding the inputs to the initial population
             for i, mol in enumerate(self._seed_mol):
                 individual = Individual(mol, idx = i)
                 if individual.pdbqt:
                     self.pop.append(individual)
 
-            # Completting the population with the generated structures
+            # Completing the population with the generated structures
             for i, mol in enumerate(GenInitStructs):
                 if self.AddHs:
                     individual = Individual(Chem.AddHs(mol), idx = i + len(self._seed_mol))
@@ -1194,7 +1222,7 @@ class GA:
                 if individual.pdbqt:
                     self.pop.append(individual)
 
-            # Make sure that the population do not have more than popsize members and it is without repeated elemnts.
+            # Make sure that the population do not have more than popsize members and it is without repeated elements.
             # That could happens if seed_mol has more molecules that popsize
             self.pop = list(set(self.pop))[:self.popsize]
 
@@ -1202,10 +1230,8 @@ class GA:
             # Creating the arguments
             args_list = []
             # Make a copy of the self.costfunc_kwargs
-            kwargs_copy = self.costfunc_kwargs.copy()
-            if 'wd' in getfullargspec(self.costfunc).args:
-                costfunc_jobs = tempfile.TemporaryDirectory(prefix='costfunc')
-                kwargs_copy['wd'] = costfunc_jobs.name
+                    # Make a copy of the self.costfunc_kwargs
+            kwargs_copy, costfunc_jobs_tmp_dir = __make_kwargs_copy__(self.costfunc, self.costfunc_kwargs)
 
             for individual in self.pop:
                 args_list.append((individual, kwargs_copy))
@@ -1226,6 +1252,9 @@ class GA:
                         f"==========Serial==========:\n {e2}"
                         )
 
+            # Clean directory
+            costfunc_jobs_tmp_dir.cleanup()
+            
             # Adding generation information
             for individual in self.pop:
                 individual.genID = self.NumGens
@@ -1236,15 +1265,19 @@ class GA:
                 'generated':len(self.pop[:])
             }
 
-            if 'wd' in getfullargspec(self.costfunc).args: shutil.rmtree(costfunc_jobs.name)
-
             # Print some information of the initial population
             print(f"Initial Population: Best Individual: {min(self.pop)}")
             print(f"Accepted rate: {self.acceptance[self.NumGens]['accepted']} / {self.acceptance[self.NumGens]['generated']}\n")
             # Updating the info of the first individual (parent) to print at the end how well performed the method (cost function)
             # Because How the population was initialized and because we are using pool.imap (ordered). The parent is the first Individual of self.pop.
             # We have to use deepcopy because Individual is a mutable object
-            self.InitIndividual = deepcopy(min(self.pop[:len(self._seed_mol)]))
+            # Because above set were used, we have to sorter based on idx
+
+            self.InitIndividual = deepcopy(
+                min(
+                    sorted(self.pop, key=lambda x:x.idx)[:len(self._seed_mol)]
+                )
+            )
 
             # Best Cost of Iterations
             self.best_cost = []
@@ -1290,10 +1323,7 @@ class GA:
                 # Creating the arguments
                 args_list = []
                 # Make a copy of the self.costfunc_kwargs
-                kwargs_copy = self.costfunc_kwargs.copy()
-                if 'wd' in getfullargspec(self.costfunc).args:
-                    costfunc_jobs = tempfile.TemporaryDirectory(prefix='costfunc')
-                    kwargs_copy['wd'] = costfunc_jobs.name
+                kwargs_copy, costfunc_jobs_tmp_dir = __make_kwargs_copy__(self.costfunc, self.costfunc_kwargs)
 
                 NumbOfSawIndividuals = len(self.SawIndividuals)
                 for (i, individual) in enumerate(popc):
@@ -1318,7 +1348,8 @@ class GA:
                             f"=========Parellel=========:\n {e1}\n"\
                             f"==========Serial==========:\n {e2}"
                             )
-                if 'wd' in getfullargspec(self.costfunc).args: shutil.rmtree(costfunc_jobs.name)
+                # Clean directory
+                costfunc_jobs_tmp_dir.cleanup()
 
             # Merge, Sort and Select
             self.pop += popc
@@ -1365,6 +1396,9 @@ class GA:
         print(f"The cost function dropped in {self.InitIndividual - self.pop[0]} units.")
         print(f"\n{50*'=+'}\n")
 
+        # Tar errors
+        __tar_errors__('error')
+
         # Printing how long was the simulation
         print(f"Total time ({self.maxiter} generations): {time.time() - ts:>5.2f} (s).\nFinished at {datetime.datetime.now().strftime('%c')}.\n")
 
@@ -1379,7 +1413,7 @@ class GA:
         Parameters
         ----------
         individual : Individual
-            The individula to mutate.
+            The individual to mutate.
 
         Returns
         -------
@@ -1421,7 +1455,7 @@ class GA:
         Parameters
         ----------
         title : str
-            Name of the object which will be compleated with the correposnding extension depending if compress is set to True or False.
+            Name of the object which will be completed with the corresponding extension depending if compress is set to True or False.
         compress : bool, optional
             Use compression, by default False. If True :meth:`moldrug.utils.compressed_pickle` will be used;
             if not :meth:`moldrug.utils.full_pickle` will be used instead.
